@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -64,7 +64,6 @@ import org.apache.commons.httpclient.HttpClient;
 import org.apache.commons.httpclient.HttpException;
 import org.apache.commons.httpclient.HttpMethodBase;
 import org.apache.commons.httpclient.HttpStatus;
-import org.apache.commons.httpclient.MultiThreadedHttpConnectionManager;
 import org.apache.commons.httpclient.NameValuePair;
 import org.apache.commons.httpclient.URI;
 import org.apache.commons.httpclient.URIException;
@@ -90,7 +89,6 @@ import org.apache.commons.httpclient.util.EncodingUtil;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.apache.commons.logging.impl.SimpleLog;
-import com.openexchange.subscribe.crawler.AnchorsByLinkRegexStep;
 
 
 /**
@@ -103,8 +101,11 @@ public class CrawlerWebConnection extends HttpWebConnection {
     private final WebClient webClient_;
     private HttpClient httpClient_;
     private String virtualHost_;
-    private static Log LOG = LogFactory.getLog(CrawlerWebConnection.class);
+    private static Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(CrawlerWebConnection.class));
     private boolean quirkyCookieQuotes;
+    private boolean switchUserAgent;
+    private final String mobileUserAgent = "Mozilla/5.0 (iPhone; U; CPU iPhone OS 3_0 like Mac OS X; en-us) AppleWebKit/528.18 (KHTML, like Gecko) Version/4.0 Mobile/7A341 Safari/528.16";
+    private final String normalUserAgent = BrowserVersion.FIREFOX_3.getUserAgent();
 
     /**
      * Initializes a new {@link CrawlerWebConnection}.
@@ -289,7 +290,15 @@ public class CrawlerWebConnection extends HttpWebConnection {
             }
         }
 
-        httpMethod.setRequestHeader("User-Agent", webClient_.getBrowserVersion().getUserAgent());
+        if (switchUserAgent) {
+            if (webClient_.getBrowserVersion().getUserAgent().equals(mobileUserAgent)){
+                httpMethod.setRequestHeader("User-Agent", normalUserAgent);
+            } else {
+                httpMethod.setRequestHeader("User-Agent", mobileUserAgent);
+            }
+        } else {
+            httpMethod.setRequestHeader("User-Agent", webClient_.getBrowserVersion().getUserAgent());            
+        }    
 
         writeRequestHeadersToHttpMethod(httpMethod, webRequestSettings.getAdditionalHeaders());
         httpMethod.setFollowRedirects(false);
@@ -427,8 +436,8 @@ public class CrawlerWebConnection extends HttpWebConnection {
      * @return the <tt>HttpClient</tt> that will be used by this WebConnection
      */
     protected HttpClient createHttpClient() {
-        final MultiThreadedHttpConnectionManager connectionManager = new MultiThreadedHttpConnectionManager();
-        return new HttpClient(connectionManager);
+        //final MultiThreadedHttpConnectionManager connectionManager = new MultiThreadedHttpConnectionManager();
+        return new HttpClient(/*connectionManager*/); // Seems we're leaking connections somewhere. Use the default connection manager here. 
     }
 
 
@@ -574,5 +583,9 @@ public class CrawlerWebConnection extends HttpWebConnection {
         this.quirkyCookieQuotes = quirkyCookieQuotes;
     }
 
+    public void switchUserAgent(){
+        if (this.switchUserAgent) {this.switchUserAgent = false;}
+        else {this.switchUserAgent = true;}
+    }
     
 }
