@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -80,7 +80,7 @@ public class ContactObjectsByPageAndPagePartSequenceStep extends AbstractStep<Co
 
     private PagePartSequence pageParts;
 
-    private static final Log LOG = LogFactory.getLog(ContactObjectsByPageAndPagePartSequenceStep.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(ContactObjectsByPageAndPagePartSequenceStep.class));
 
     public ContactObjectsByPageAndPagePartSequenceStep() {
         
