@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,6 +51,7 @@ package com.openexchange.subscribe.crawler;
 
 import java.io.ByteArrayInputStream;
 import java.io.IOException;
+import java.util.ArrayList;
 import java.util.List;
 import java.util.TimeZone;
 import java.util.Vector;
@@ -78,9 +79,9 @@ public class ContactObjectsByVcardFileStep extends AbstractStep<Contact[], Page>
 
     private static final ContactSanitizer SANITIZER = new ContactSanitizer();
 
-    private static final Log LOG = LogFactory.getLog(ContactObjectsByVcardFileStep.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(ContactObjectsByVcardFileStep.class));
 
-    private List<String> unwantedLines;
+    private List<String> unwantedLines = new ArrayList<String>();
 
     public ContactObjectsByVcardFileStep() {
 
