@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -80,7 +80,7 @@ public class GoogleCalendarICalStep extends AbstractStep<CalendarDataObject[], U
 
     private String url;
 
-    private static final Log LOG = LogFactory.getLog(GoogleCalendarICalStep.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(GoogleCalendarICalStep.class));
 
     public GoogleCalendarICalStep() {
         super();
@@ -95,11 +95,9 @@ public class GoogleCalendarICalStep extends AbstractStep<CalendarDataObject[], U
     public void execute(WebClient webClient) {
         ArrayList<CalendarDataObject> tempEvents = new ArrayList<CalendarDataObject>();
         ArrayList<CalendarDataObject> events = new ArrayList<CalendarDataObject>();
-
         try {
             Page page = webClient.getPage(url);
             byte[] bytes = page.getWebResponse().getContentAsBytes();
-
             // Unzip
             int BUFFER = 1024;
             // BufferedOutputStream dest = null;
