@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,7 +51,11 @@ package com.openexchange.subscribe.crawler;
 
 import java.io.IOException;
 import java.net.MalformedURLException;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+import com.gargoylesoftware.htmlunit.ElementNotFoundException;
 import com.gargoylesoftware.htmlunit.FailingHttpStatusCodeException;
+import com.gargoylesoftware.htmlunit.Page;
 import com.gargoylesoftware.htmlunit.WebClient;
 import com.gargoylesoftware.htmlunit.html.HtmlAnchor;
 import com.gargoylesoftware.htmlunit.html.HtmlForm;
@@ -61,6 +65,7 @@ import com.gargoylesoftware.htmlunit.html.HtmlTextInput;
 import com.openexchange.subscribe.SubscriptionErrorMessage;
 import com.openexchange.subscribe.SubscriptionException;
 import com.openexchange.subscribe.crawler.internal.AbstractStep;
+import com.openexchange.subscribe.crawler.internal.HasLoginPage;
 import com.openexchange.subscribe.crawler.internal.LoginStep;
 
 /**
@@ -68,9 +73,13 @@ import com.openexchange.subscribe.crawler.internal.LoginStep;
  * 
  * @author <a href="mailto:karsten.will@open-xchange.com">Karsten Will</a>
  */
-public class LoginPageStep extends AbstractStep<HtmlPage, Object> implements LoginStep {
+public class LoginPageStep extends AbstractStep<HtmlPage, Object> implements LoginStep, HasLoginPage {
 
     private String url, username, password, nameOfLoginForm, nameOfUserField, nameOfPasswordField, linkAvailableAfterLogin, baseUrl;
+    
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(LoginPageStep.class));
+    
+    private Page loginPage;
 
     public LoginPageStep() {
     }
@@ -89,10 +98,11 @@ public class LoginPageStep extends AbstractStep<HtmlPage, Object> implements Log
 
     @Override
     public void execute(final WebClient webClient) throws SubscriptionException {
-        HtmlPage loginPage;
-        try {
+        HtmlPage loginPage = null;;
+        try { 
             // Get the page, fill in the credentials and submit the login form
             loginPage = webClient.getPage(url);
+            this.loginPage = loginPage;
             final HtmlForm loginForm = loginPage.getFormByName(nameOfLoginForm);
             final HtmlTextInput userfield = loginForm.getInputByName(nameOfUserField);
             userfield.setValueAttribute(username);
@@ -118,6 +128,9 @@ public class LoginPageStep extends AbstractStep<HtmlPage, Object> implements Log
             throw SubscriptionErrorMessage.COMMUNICATION_PROBLEM.create(e);
         } catch (final IOException e) {
             throw SubscriptionErrorMessage.COMMUNICATION_PROBLEM.create(e);
+        } catch (ElementNotFoundException e){            
+            LOG.error("The page that does not contain the needed form : \n" + loginPage.getWebResponse().getContentAsString());
+            throw SubscriptionErrorMessage.COMMUNICATION_PROBLEM.create(e);
         }
     }
 
@@ -193,4 +206,10 @@ public class LoginPageStep extends AbstractStep<HtmlPage, Object> implements Log
         this.baseUrl = baseUrl;
     }
 
+    
+    public Page getLoginPage() {
+        return loginPage;
+    }
+
+    
 }
