@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,14 +49,11 @@
 
 package com.openexchange.subscribe.crawler;
 
-import java.io.IOException;
-import java.net.MalformedURLException;
-import com.gargoylesoftware.htmlunit.FailingHttpStatusCodeException;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import com.gargoylesoftware.htmlunit.WebClient;
 import com.gargoylesoftware.htmlunit.html.FrameWindow;
-import com.gargoylesoftware.htmlunit.html.HtmlAnchor;
 import com.gargoylesoftware.htmlunit.html.HtmlPage;
-import com.openexchange.subscribe.SubscriptionErrorMessage;
 import com.openexchange.subscribe.SubscriptionException;
 import com.openexchange.subscribe.crawler.internal.AbstractStep;
 
@@ -72,6 +69,8 @@ public class PageByFrameNumberStep extends AbstractStep<HtmlPage, HtmlPage> {
     protected boolean executedSuccessfully;
     
     private int frameNumber;
+    
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(PageByFrameNumberStep.class));
 
     public PageByFrameNumberStep() {
         super();
@@ -90,7 +89,8 @@ public class PageByFrameNumberStep extends AbstractStep<HtmlPage, HtmlPage> {
         
         for (FrameWindow frame : input.getFrames()){
             if (index == frameNumber){
-                output = (HtmlPage) frame.getEnclosedPage();
+                output = (HtmlPage) frame.getEnclosedPage();                
+                LOG.debug("Frame selected : " + frame.getName()+ "\n" + ((HtmlPage) frame.getEnclosedPage()).getWebResponse().getContentAsString());
             }
             index ++;
         }
