@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -74,7 +74,7 @@ public class PageByLinkRegexStep extends AbstractStep<HtmlPage, HtmlPage>{
 
     protected boolean executedSuccessfully;
     
-    private static Log LOG = LogFactory.getLog(PageByLinkRegexStep.class);
+    private static Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(PageByLinkRegexStep.class));
 
     public PageByLinkRegexStep() {
         super();
@@ -96,6 +96,10 @@ public class PageByLinkRegexStep extends AbstractStep<HtmlPage, HtmlPage>{
                 }
             }
             
+            if (debuggingEnabled){
+                openPageInBrowser(output);
+            }
+            
             if (output != null) {
                 executedSuccessfully = true;                 
             } else {
