@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -71,6 +71,8 @@ public class TextPagesByLinkStep extends AbstractStep<List<TextPage>, HtmlPage>{
     private String urlBeforeOffset, urlAfterOffset, linkpart;
 
     private int offset;
+    
+    private ArrayList<String> collectedLinks;
 
     public TextPagesByLinkStep() {
         output = new ArrayList<TextPage>();
@@ -87,6 +89,7 @@ public class TextPagesByLinkStep extends AbstractStep<List<TextPage>, HtmlPage>{
 
     @Override
     public void execute(final WebClient webClient) throws SubscriptionException {
+        collectedLinks = new ArrayList<String>(); 
         try {
 
             int tempOffset = 0;
@@ -97,9 +100,10 @@ public class TextPagesByLinkStep extends AbstractStep<List<TextPage>, HtmlPage>{
                 final HtmlPage tempPage = webClient.getPage(urlBeforeOffset + Integer.toString(tempOffset) + urlAfterOffset);
                 final List<HtmlAnchor> allLinks = tempPage.getAnchors();
                 for (final HtmlAnchor link : allLinks) {
-                    if (link.getHrefAttribute().startsWith(linkpart)) {
+                    if (link.getHrefAttribute().startsWith(linkpart) && !collectedLinks.contains(link.getHrefAttribute())) {
                         oneSuccess = true;
                         final TextPage tempTextPage = link.click();
+                        collectedLinks.add(link.getHrefAttribute());
                         output.add(tempTextPage);
                     }
                 }
