@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -73,7 +73,7 @@ public class UnexpectedPageByMultiselectStep extends AbstractStep<UnexpectedPage
     
     private int formNumber;
     
-    private static final Log LOG = LogFactory.getLog(UnexpectedPageByMultiselectStep.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(UnexpectedPageByMultiselectStep.class));
     
     public UnexpectedPageByMultiselectStep(){
         
