@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -75,6 +75,8 @@ public abstract class AbstractStep<O,I> implements Step<O,I>{
     protected I input;
     
     protected boolean debuggingEnabled;
+    
+    protected boolean switchUserAgent;
 
     protected AbstractStep() {
         super();
@@ -119,6 +121,19 @@ public abstract class AbstractStep<O,I> implements Step<O,I>{
         
     }
     
+    public I getInput() {
+        return input;
+    }
+    
+    public boolean isSwitchUserAgent() {
+        return switchUserAgent;
+    }
+
+    
+    public void setSwitchUserAgent(boolean switchUserAgent) {
+        this.switchUserAgent = switchUserAgent;
+    }
+
     // Convenience Methods for Development / Debugging
     public boolean isDebuggingEnabled() {
         return debuggingEnabled;
@@ -129,22 +144,30 @@ public abstract class AbstractStep<O,I> implements Step<O,I>{
         this.debuggingEnabled = debuggingEnabled;
     }
     
+    // this opens the current page in the developers browser while debugging for a fast overview.
     protected void openPageInBrowser(Page page){
         File file = new File ("./crawlerTestPage.html");
         Writer output = null;                            
         try {
           output = new BufferedWriter(new FileWriter(file));
           output.write( page.getWebResponse().getContentAsString() );
-          Runtime.getRuntime().exec("open -a Safari ./crawlerTestPage.html");
+          // Check on which Operating System this runs
+          if (System.getProperty("os.name").contains("Mac")){
+              Runtime.getRuntime().exec("open -a Safari ./crawlerTestPage.html");
+          } else if (System.getProperty("os.name").contains("Windows")){
+              Runtime.getRuntime().exec("cmd.exe /C start ./crawlerTestPage.html");
+          } else {
+              // Linux (hopefully)
+              Runtime.getRuntime().exec("firefox ./crawlerTestPage.html &");
+          }
+          //windows: iexplore http://www.example.com
         } catch (IOException e) {
-            // TODO Auto-generated catch block
             e.printStackTrace();
         }
         finally {
           try {
             output.close();
         } catch (IOException e) {
-            // TODO Auto-generated catch block
             e.printStackTrace();
         } 
         }
