@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,12 +51,18 @@ package com.openexchange.subscribe.crawler.internal;
 
 import static com.openexchange.subscribe.crawler.internal.FormStrings.FORM_LABEL_LOGIN;
 import static com.openexchange.subscribe.crawler.internal.FormStrings.FORM_LABEL_PASSWORD;
+import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
+import java.util.List;
 import java.util.Map;
+import java.util.UUID;
 import com.openexchange.datatypes.genericonf.DynamicFormDescription;
 import com.openexchange.datatypes.genericonf.FormElement;
+import com.openexchange.groupware.container.Contact;
 import com.openexchange.groupware.container.FolderObject;
+import com.openexchange.session.Session;
+import com.openexchange.sessiond.SessiondService;
 import com.openexchange.subscribe.AbstractSubscribeService;
 import com.openexchange.subscribe.Subscription;
 import com.openexchange.subscribe.SubscriptionException;
@@ -83,13 +89,13 @@ public class GenericSubscribeService extends AbstractSubscribeService {
     
     private final Activator activator;
     
-    private boolean enableJavascript;
+    private final boolean enableJavascript;
     
     private int module = FolderObject.CONTACT;
 
-    public GenericSubscribeService(final String displayName, final String id, final int module, final String workflowString, final int priority, Activator activator, boolean enableJavascript) {
+    public GenericSubscribeService(final String displayName, final String id, final int module, final String workflowString, final int priority, final Activator activator, final boolean enableJavascript) {
         FORM.add(FormElement.input(LOGIN, FORM_LABEL_LOGIN)).add(FormElement.password("password", FORM_LABEL_PASSWORD));
-
+        addExtraFields(FORM);
         SOURCE.setDisplayName(displayName);
         SOURCE.setId(id);
         SOURCE.setFormDescription(FORM);
@@ -102,6 +108,10 @@ public class GenericSubscribeService extends AbstractSubscribeService {
         this.module = module;
     }
 
+    protected void addExtraFields(final DynamicFormDescription form) {
+        // May be overridden to include extra fields
+    }
+
     public SubscriptionSource getSubscriptionSource() {
         return SOURCE;
     }
@@ -116,6 +126,17 @@ public class GenericSubscribeService extends AbstractSubscribeService {
         workflow.setSubscription(subscription);
         workflow.setEnableJavascript(enableJavascript);
         final Map<String, Object> configuration = subscription.getConfiguration();
+        // All contacts should get a UUID for aggregation
+        if (this.module == FolderObject.CONTACT){
+            final List list =  Arrays.asList(workflow.execute((String) configuration.get("login"), (String) configuration.get("password")));
+            final List<Contact> contacts = new ArrayList<Contact>();
+            for (final Object object : list){
+                final Contact contact = (Contact) object;
+                contact.setUserField20(UUID.randomUUID().toString());
+                contacts.add(contact);
+            }
+            return contacts;
+        }
         return Arrays.asList(workflow.execute((String) configuration.get("login"), (String) configuration.get("password")));
     }
 
@@ -134,14 +155,42 @@ public class GenericSubscribeService extends AbstractSubscribeService {
     public void modifyIncoming(final Subscription subscription) throws SubscriptionException {
         super.modifyIncoming(subscription);
         final Map<String, Object> configuration = subscription.getConfiguration();
-        encrypt(configuration, PASSWORD);
+        try {
+            encrypt(subscription.getSession(), configuration, PASSWORD);
+        } catch (final UnsupportedOperationException e) {
+            // May be thrown by TargetFolderSession, retry with real session
+            final SessiondService service = SessiondService.SERVICE_REFERENCE.get();
+            if (null == service) {
+                throw e;
+            }
+            final Session fake = subscription.getSession();
+            final Session session = service.getAnyActiveSessionForUser(fake.getUserId(), fake.getContextId());
+            if (null == session) {
+                throw e;
+            }
+            encrypt(session, configuration, PASSWORD);
+        }
     }
 
     @Override
     public void modifyOutgoing(final Subscription subscription) throws SubscriptionException {
         super.modifyOutgoing(subscription);
         final Map<String, Object> configuration = subscription.getConfiguration();
-        decrypt(configuration, PASSWORD);
+        try {
+            decrypt(subscription, subscription.getSession(), configuration, PASSWORD);
+        } catch (final UnsupportedOperationException e) {
+            // May be thrown by TargetFolderSession, retry with real session
+            final SessiondService service = SessiondService.SERVICE_REFERENCE.get();
+            if (null == service) {
+                throw e;
+            }
+            final Session fake = subscription.getSession();
+            final Session session = service.getAnyActiveSessionForUser(fake.getUserId(), fake.getContextId());
+            if (null == session) {
+                throw e;
+            }
+            decrypt(subscription, session, configuration, PASSWORD);
+        }
         subscription.setDisplayName((String) subscription.getConfiguration().get(LOGIN));
     }
 
