@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -71,21 +71,23 @@ public class GenericSubscribeServiceForGoogleCalendarICalTest extends GenericSub
         crawler.setId("com.openexchange.subscribe.crawler.google.calendar");
         crawler.setModule(FolderObject.CALENDAR);
         crawler.setCrawlerApiVersion(618);
-        crawler.setPriority(2);
+        crawler.setPriority(6);
         // crawler.setJavascriptEnabled(true);
 
         ArrayList<Step> steps = new ArrayList<Step>();
-        steps.add(new LoginPageByFormActionStep(
+        LoginPageByFormActionStep loginStep = new LoginPageByFormActionStep(
             "Log into Google Calendar",
-            "https://calendar.google.com",
+            "https://www.google.com/accounts/ServiceLogin?service=cl",
             "",
             "",
-            "https://www.google.com/accounts/ServiceLoginAuth",
+            "https://accounts.google.com/ServiceLoginAuth",
             "Email",
             "Passwd",
-            "logout",
+            ".*Logout.*",
             1,
-            "https://calendar.google.com"));      
+            "https://calendar.google.com");
+        loginStep.setGeoCheckString("signing in to your account from a new location");
+        steps.add(loginStep);
         steps.add(new GoogleCalendarICalStep("Call the url to get the calendar-export-file", "https://www.google.com/calendar/exporticalzip"));
 
         Workflow workflow = new Workflow(steps);
