@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -68,6 +68,7 @@ public class GenericSubscribeServiceForXingTest extends GenericSubscribeServiceT
         CrawlerDescription crawler = new CrawlerDescription();
         crawler.setDisplayName("XING");
         crawler.setId("com.openexchange.subscribe.xing");
+        crawler.setPriority(2);
 
         List<Step> steps = new LinkedList<Step>();
         steps.add(new LoginPageStep(
@@ -82,7 +83,7 @@ public class GenericSubscribeServiceForXingTest extends GenericSubscribeServiceT
             "https://www.xing.com"));
         steps.add(new TextPagesByLinkStep(
             "Get all vcards as text pages",
-            "https://www.xing.com/app/contact?notags_filter=0;card_mode=0;search_filter=;tags_filter=;offset=",
+            "https://www.xing.com/app/contact?notags_filter=0;search_filter=;tags_filter=;offset=",
             10,
             "",
             "/app/contact?op=vcard;scr_id"));
@@ -91,10 +92,10 @@ public class GenericSubscribeServiceForXingTest extends GenericSubscribeServiceT
         Workflow workflow = new Workflow(steps);
         crawler.setWorkflowString(Yaml.dump(workflow));
 
-        findOutIfThereAreContactsForThisConfiguration(username, password, crawler);
+        // findOutIfThereAreContactsForThisConfiguration(username, password, crawler, true);
         // uncomment this if the if the crawler description was updated to get the new config-files
         // file get written to /conf/crawlers in this bundle as well as /crawlers in open-xchange-development
-        // dumpThis(crawler, crawler.getDisplayName());
+        dumpThis(crawler, crawler.getDisplayName());
     }
 
 }
