@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -59,6 +59,7 @@ import org.ho.yaml.Yaml;
 import com.openexchange.config.SimConfigurationService;
 import com.openexchange.groupware.container.Appointment;
 import com.openexchange.groupware.container.Contact;
+import com.openexchange.groupware.tasks.Task;
 import com.openexchange.subscribe.SubscriptionException;
 import com.openexchange.subscribe.crawler.internal.GenericSubscribeService;
 import com.openexchange.subscribe.crawler.osgi.Activator;
@@ -69,9 +70,9 @@ import com.openexchange.subscribe.crawler.osgi.Activator;
 public abstract class GenericSubscribeServiceTestHelpers extends TestCase {
 
     public static final String VALID_EMAIL_REGEX = "([a-z@A-Z0-9\\.\\-\\{\\}\\#\\|\\^\\$\\*\\+\\?\\'\\/!%&=_`~]*)";
-    public static final String VALID_NAME = "([a-zA-Z\\s\u00e4\u00f6\u00fc\u00df-]*)";
+    public static final String VALID_NAME = "([a-zA-Z\\s\u00e4\u00f6\u00fc\u00df-\u00e9\u00e8]*)";
     public static final String VALID_PHONE_REGEX = "([0-9\\s\\+\\-\\/\\(\\)]*)";
-    public static final String VALID_ADDRESS_PART = "[a-zA-Z0-9\\s\u00e4\u00f6\u00fc\u00df]*";
+    public static final String VALID_ADDRESS_PART = "[a-zA-Z0-9\\.\\s\u00e4\u00f6\u00fc\u00df]*";
     
     private HashMap<String, String> map;
     ArrayList<CrawlerDescription> crawlers;
@@ -93,7 +94,7 @@ public abstract class GenericSubscribeServiceTestHelpers extends TestCase {
         try {
             // insert path to credentials-file here (switch for automated tests (Hudson) / local tests)
             map = (HashMap<String, String>) Yaml.load(getSecretsFile());
-            // map = (HashMap<String, String>) Yaml.load(new File("/Users/karstenwill/Documents/Development/crawlerCredentials.yml"));
+            // map = (HashMap<String, String>) Yaml.load(new File("/Users/karstenwill/Documents/open-xchange/crawler/crawlerCredentials.yml"));
         } catch (FileNotFoundException e) {
             e.printStackTrace();
         }
@@ -102,8 +103,12 @@ public abstract class GenericSubscribeServiceTestHelpers extends TestCase {
         //test with the real crawlers (switch for automated tests (Hudson) / local tests)
         config.stringProperties.put("com.openexchange.subscribe.crawler.path", System.getProperty("crawlersConf"));
         // config.stringProperties.put("com.openexchange.subscribe.crawler.path", "conf/crawlers/");
-        activator = new Activator();
+        activator = new Activator();        
         crawlers = activator.getCrawlersFromFilesystem(config);
+        
+        // insert ical-Parser class (switch for automated tests (Hudson) / local tests)
+        //activator.setICalParser(new com.openexchange.data.conversion.ical.ical4j.ICal4JParser());
+        activator.setICalParser(null);
     }
     
     protected void findOutIfThereAreContactsForThisConfiguration(final String username, final String password, final CrawlerDescription crawler) {
@@ -142,8 +147,11 @@ public abstract class GenericSubscribeServiceTestHelpers extends TestCase {
                 System.out.println("contacts first name : " + contact.getGivenName());
                 System.out.println("contacts last name : " + contact.getSurName());
                 System.out.println("contacts title : " + contact.getTitle());
-                System.out.println("contacts email address : " + contact.getEmail1());
-                System.out.println("contacts mobile phone number : " + contact.getCellularTelephone1());
+                System.out.println("contacts position : " + contact.getPosition());
+                System.out.println("contacts business email address : " + contact.getEmail1());
+                System.out.println("contacts private email address : " + contact.getEmail2());
+                System.out.println("contacts business mobile phone number : " + contact.getCellularTelephone1());
+                System.out.println("contacts private mobile phone number : " + contact.getCellularTelephone2());
                 System.out.println("contacts work phone number : " + contact.getTelephoneBusiness1());
                 System.out.println("contacts home phone number : " + contact.getTelephoneHome1());
                 System.out.println("contacts instant messenger : " + contact.getInstantMessenger1());
@@ -207,6 +215,43 @@ public abstract class GenericSubscribeServiceTestHelpers extends TestCase {
         System.out.println("Time : " + Long.toString((after - before) / 1000) + " seconds");
     }
 
+    protected void findOutIfThereAreTasksForThisConfiguration(final String username, final String password, final CrawlerDescription crawler, final boolean verbose, final boolean enableJavascript) {
+        Calendar rightNow = Calendar.getInstance();
+        final long before = rightNow.getTime().getTime();
+        // create a GenericSubscribeService that uses this CrawlerDescription
+        final GenericSubscribeService service = new GenericSubscribeService(
+            crawler.getDisplayName(),
+            crawler.getId(),
+            crawler.getModule(),
+            crawler.getWorkflowString(),
+            crawler.getPriority(),
+            activator,
+            enableJavascript);
+
+        final Workflow testWorkflow = service.getWorkflow();
+        testWorkflow.setDebuggingEnabled(true);
+        Task[] tasks = new Task[0];
+        try {
+            tasks = (Task[])testWorkflow.execute(username, password);
+        } catch (final SubscriptionException e) {
+            e.printStackTrace();
+        }
+        assertTrue("There are no tasks for crawler : " + crawler.getDisplayName(), tasks.length != 0);
+        if (verbose){
+            for (final Task task : tasks) {
+                System.out.println("task retrieved is : " + task.getTitle());                
+                System.out.println("Start Date is : " + task.getStartDate());
+                System.out.println("End Date is : " + task.getEndDate());                
+                System.out.println("Description is : " + task.getNote());
+                System.out.println("----------");
+            }
+        }
+        System.out.println("Number of events retrieved : " + Integer.toString(tasks.length));
+        rightNow = Calendar.getInstance();
+        final long after = rightNow.getTime().getTime();
+        System.out.println("Time : " + Long.toString((after - before) / 1000) + " seconds");
+    }
+    
     /**
      * Create files for this CrawlerDescription that will be used by the live system
      * 
@@ -222,12 +267,16 @@ public abstract class GenericSubscribeServiceTestHelpers extends TestCase {
     }
 
     protected void checkSingleCrawler(String nameOfCrawlerToCheck) {
+        boolean crawlerFound = false;
+        boolean credentialsFound = false;
         for (CrawlerDescription crawler : crawlers) {
             String crawlerName = crawler.getDisplayName();
             if (crawlerName.equals(nameOfCrawlerToCheck)) {
+                crawlerFound = true;
                 String [] domains = {".de",".com",".uk",".fr",".es",".nl"};
                 for (String domain : domains){
                     if (map.containsKey(crawlerName+"_user" + domain) && map.containsKey(crawlerName+"_password" + domain)){
+                        credentialsFound = true;
                         String username = map.get(crawlerName+"_user" + domain);
                         String password = map.get(crawlerName+"_password" + domain);
                         System.out.println("***** Testing crawler : " + crawlerName + " for domain : " + domain);
@@ -236,6 +285,8 @@ public abstract class GenericSubscribeServiceTestHelpers extends TestCase {
                 }
             }
         }
+        if (! crawlerFound){fail("No description found for crawler : " + nameOfCrawlerToCheck);}
+        if (! credentialsFound) {fail("No credentials found for crawler : " + nameOfCrawlerToCheck);}
 
     }
 
